package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/InnerClass.class */
public final class InnerClass implements Cloneable, Node {
    private int innerClassIndex;
    private int outerClassIndex;
    private int innerNameIndex;
    private int innerAccessFlags;

    /* JADX INFO: Access modifiers changed from: package-private */
    public InnerClass(DataInput file) throws IOException {
        this(file.readUnsignedShort(), file.readUnsignedShort(), file.readUnsignedShort(), file.readUnsignedShort());
    }

    public InnerClass(InnerClass c) {
        this(c.getInnerClassIndex(), c.getOuterClassIndex(), c.getInnerNameIndex(), c.getInnerAccessFlags());
    }

    public InnerClass(int innerClassIndex, int outerClassIndex, int innerNameIndex, int innerAccessFlags) {
        this.innerClassIndex = innerClassIndex;
        this.outerClassIndex = outerClassIndex;
        this.innerNameIndex = innerNameIndex;
        this.innerAccessFlags = innerAccessFlags;
    }

    @Override // org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitInnerClass(this);
    }

    public InnerClass copy() {
        try {
            return (InnerClass) clone();
        } catch (CloneNotSupportedException e) {
            return null;
        }
    }

    public void dump(DataOutputStream file) throws IOException {
        file.writeShort(this.innerClassIndex);
        file.writeShort(this.outerClassIndex);
        file.writeShort(this.innerNameIndex);
        file.writeShort(this.innerAccessFlags);
    }

    public int getInnerAccessFlags() {
        return this.innerAccessFlags;
    }

    public int getInnerClassIndex() {
        return this.innerClassIndex;
    }

    public int getInnerNameIndex() {
        return this.innerNameIndex;
    }

    public int getOuterClassIndex() {
        return this.outerClassIndex;
    }

    public void setInnerAccessFlags(int innerAccessFlags) {
        this.innerAccessFlags = innerAccessFlags;
    }

    public void setInnerClassIndex(int innerClassIndex) {
        this.innerClassIndex = innerClassIndex;
    }

    public void setInnerNameIndex(int innerNameIndex) {
        this.innerNameIndex = innerNameIndex;
    }

    public void setOuterClassIndex(int outerClassIndex) {
        this.outerClassIndex = outerClassIndex;
    }

    public String toString() {
        return "InnerClass(" + this.innerClassIndex + ", " + this.outerClassIndex + ", " + this.innerNameIndex + ", " + this.innerAccessFlags + ")";
    }

    public String toString(ConstantPool constantPool) {
        String outerClassName;
        String innerName;
        String innerClassName = constantPool.getConstantString(this.innerClassIndex, (byte) 7);
        String innerClassName2 = Utility.compactClassName(innerClassName, false);
        if (this.outerClassIndex != 0) {
            String outerClassName2 = constantPool.getConstantString(this.outerClassIndex, (byte) 7);
            outerClassName = " of class " + Utility.compactClassName(outerClassName2, false);
        } else {
            outerClassName = "";
        }
        if (this.innerNameIndex != 0) {
            innerName = constantPool.getConstantUtf8(this.innerNameIndex).getBytes();
        } else {
            innerName = "(anonymous)";
        }
        String access = Utility.accessToString(this.innerAccessFlags, true);
        return "  " + (access.isEmpty() ? "" : access + " ") + innerName + "=class " + innerClassName2 + outerClassName;
    }
}
